#include <iostream>
#include <cmath>
#include <vector>
#include <tuple>
#include <limits>
using namespace std;

#define int long long 
#define ld long double

typedef pair<ld, ld> Point;

ld pointToLineDistance(Point P, Point P1, Point P2) {
    ld x0 = P.first, y0 = P.second;
    ld x1 = P1.first, y1 = P1.second;
    ld x2 = P2.first, y2 = P2.second;
    
    ld numerator = abs((y2 - y1) * x0 - (x2 - x1) * y0 + x2 * y1 - y2 * x1);
    ld denominator = sqrtl((y2 - y1) * (y2 - y1) + (x2 - x1) * (x2 - x1));
    
    return numerator / denominator;
}


ld totalDistanceToLine(const vector<Point>& points, Point P1, Point P2) {
    ld totalDistance = 0.0;
    for (const auto& point : points) {
        totalDistance += pointToLineDistance(point, P1, P2);
    }
    return totalDistance;
}

signed main() {
    ld x1, y1, x2, y2, x3, y3;
    cin >> x1 >> y1 >> x2 >> y2 >> x3 >> y3;

    vector<Point> points = {{x1, y1}, {x2, y2}, {x3, y3}};
    vector<Point> candidates = {{x1, y1}, {x2, y2}, {x3, y3}};
    
    ld minDistance = numeric_limits<ld>::max();
    Point bestP1, bestP2;

    for (int i = 0; i < 3; ++i) {
        for (int j = i + 1; j < 3; ++j) {
            Point P1 = points[i];
            Point P2 = points[j];
            ld distance = totalDistanceToLine(points, P1, P2);
            if (distance < minDistance) {
                minDistance = distance;
                bestP1 = P1;
                bestP2 = P2;
            }
        }
    }

    cout << static_cast<int>(bestP1.first) << " " << static_cast<int>(bestP1.second) << " "
         << static_cast<int>(bestP2.first) << " " << static_cast<int>(bestP2.second) << endl;

    return 0;
}
