
#include <iostream>
#include <vector>
#include <cmath>
#include <iomanip>

using namespace std;

const double EPS = 1e-4;

// Функция для проверки возможности выполнения маршрута
bool solve(int x0, int y0, int x1, int y1, const vector<int>& jumps, vector<pair<double, double>>& result) {
    int n = jumps.size();
    result.clear();

    double curX = x0, curY = y0;
    double dx = x1 - x0, dy = y1 - y0;
    double dist = sqrt(dx * dx + dy * dy);
    double totalJumps = 0;

    for (int jump : jumps) {
        totalJumps += jump;
    }

    // Если сумма прыжков меньше расстояния до цели — невозможно
    if (totalJumps < dist) {
        return false;
    }

    // Построение маршрута
    for (int i = 0; i < n; ++i) {
        if (i == n - 1) {
            // Последний прыжок должен точно попасть в цель
            result.emplace_back(x1, y1);
        } else {
            // Пропорционально распределяем направление
            double angle = atan2(dy, dx);
            double nx = curX + jumps[i] * cos(angle);
            double ny = curY + jumps[i] * sin(angle);

            result.emplace_back(nx, ny);
            curX = nx;
            curY = ny;
            dx = x1 - curX;
            dy = y1 - curY;
        }
    }

    // Проверка финального состояния
    double finalDist = sqrt((result.back().first - x1) * (result.back().first - x1) +
                            (result.back().second - y1) * (result.back().second - y1));
    return finalDist < EPS;
}

// Функция для красивого вывода числа с фиксированными нулями
void printFormattedWithZeros(double value) {
    cout << fixed << setprecision(7) << value;
}

int main() {
    int x0, y0, x1, y1, n;
    cin >> x0 >> y0 >> x1 >> y1 >> n;

    vector<int> jumps(n);
    for (int i = 0; i < n; ++i) {
        cin >> jumps[i];
    }

    vector<pair<double, double>> result;

    if (solve(x0, y0, x1, y1, jumps, result)) {
        cout << "Possible" << endl;
        for (const auto& point : result) {
            printFormattedWithZeros(point.first);
            cout << " ";
            printFormattedWithZeros(point.second);
            cout << endl;
        }
    } else {
        cout << "Impossible" << endl;
    }

    return 0;
}
