#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>
#include <limits>

using namespace std;

struct Line {
    long long a, b, c; 
};

struct Point {
    long long x, y;
};

double distanceToLine(const Line& line, const Point& point) {
    return fabs(line.a * point.x + line.b * point.y + line.c) / sqrt((double)line.a * line.a + (double)line.b * line.b);
}

Line getLineFromPoints(const Point& p1, const Point& p2) {
    Line line;
    line.a = p2.y - p1.y;
    line.b = p1.x - p2.x;
    line.c = -(line.a * p1.x + line.b * p1.y);
    return line;
}

double totalDistance(const Line& line, const vector<Point>& points) {
    double total = 0.0;
    for (const auto& point : points) {
        total += distanceToLine(line, point);
    }
    return total;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    vector<Point> houses(3);
    for (int i = 0; i < 3; ++i) {
        cin >> houses[i].x >> houses[i].y;
    }

    vector<Line> candidateLines;
    candidateLines.push_back(getLineFromPoints(houses[0], houses[1]));
    candidateLines.push_back(getLineFromPoints(houses[0], houses[2]));
    candidateLines.push_back(getLineFromPoints(houses[1], houses[2]));
    for (int i = 0; i < 3; ++i) {
        candidateLines.push_back({1, 0, -houses[i].x});
        candidateLines.push_back({0, 1, -houses[i].y}); 
    }

    double minTotalDistance = numeric_limits<double>::max();
    Line bestLine;
    for (const auto& line : candidateLines) {
        double totalDist = totalDistance(line, houses);
        if (totalDist < minTotalDistance) {
            minTotalDistance = totalDist;
            bestLine = line;
        }
    }
    cout.precision(0);
    cout << fixed;
    long long gcd_ab = __gcd(abs(bestLine.a), abs(bestLine.b));
    gcd_ab = __gcd(gcd_ab, abs(bestLine.c));
    if (gcd_ab == 0) gcd_ab = 1;
    long long a_norm = bestLine.a / gcd_ab;
    long long b_norm = bestLine.b / gcd_ab;
    long long c_norm = bestLine.c / gcd_ab;
    if (b_norm == 0) {
        long long x = -c_norm / a_norm;
        long long y1 = -1e9;
        long long y2 = y1 + 1;
        cout << x << " " << y1 << " " << x << " " << y2 << endl;
    }
    else if (a_norm == 0) {
        long long y = -c_norm / b_norm;
        long long x1 = -1e9;
        long long x2 = x1 + 1;
        cout << x1 << " " << y << " " << x2 << " " << y << endl;
    }
    else if (a_norm == -b_norm) {
        long long k = -c_norm / a_norm;
        long long x1 = 1;
        long long y1 = x1 + k;
        long long x2 = 3;
        long long y2 = x2 + k;
        cout << x1 << " " << y1 << " " << x2 << " " << y2 << endl;
    } else {
        long long dx = b_norm;
        long long dy = -a_norm;
        long long x_start = houses[0].x;
        long long y_start = houses[0].y;
        bool point_found = false;
        for (long long k = -1e9; k <= 1e9 && !point_found; k += max(abs(dx), abs(dy))) {
            x_start = k;
            y_start = (-c_norm - a_norm * x_start) / b_norm;
            if (y_start < -1e9 || y_start > 1e9) continue;
            bool coincides = false;
            for (const auto& house : houses) {
                if (x_start == house.x && y_start == house.y) {
                    coincides = true;
                    break;
                }
            }
            if (!coincides) {
                point_found = true;
                break;
            }
        }

        long long x_end = x_start + dx;
        long long y_end = y_start + dy;

        cout << x_start << " " << y_start << " " << x_end << " " << y_end << endl;
    }

    return 0;
}
