def coordinate_to_chess_notation(x, y):
    """Конвертирует координаты доски в шахматную нотацию."""
    file = chr(ord('a') + x - 1)
    rank = str(y)
    return file + rank

def main():
    import sys

    possible_positions = set((x, y) for x in range(1, 9) for y in range(1, 9))
    moves_made = []
    attempted_moves = set()

    for _ in range(7):
        if len(possible_positions) == 1:
            break

        # Генерируем все возможные ходы слона, избегая повторений
        potential_moves = []
        for dx in range(-7, 8):
            if dx == 0:
                continue
            for dy in [dx, -dx]:
                if (dx, dy) not in attempted_moves and -7 <= dy <= 7:
                    potential_moves.append((dx, dy))

        # Выбираем ход, который максимально разделит возможные позиции
        best_move = None
        min_difference = len(possible_positions)
        for dx, dy in potential_moves:
            success_positions = set()
            fail_positions = set()
            for x, y in possible_positions:
                new_x, new_y = x + dx, y + dy
                if 1 <= new_x <= 8 and 1 <= new_y <= 8:
                    success_positions.add((new_x, new_y))
                else:
                    fail_positions.add((x, y))
            difference = abs(len(success_positions) - len(fail_positions))
            if difference < min_difference:
                min_difference = difference
                best_move = (dx, dy)
            if min_difference == 0:
                break  # Нашли оптимальный ход

        if not best_move:
            break  # Нет больше ходов для попытки

        dx, dy = best_move
        attempted_moves.add((dx, dy))

        print(f"? {dx} {dy}")
        sys.stdout.flush()
        response = sys.stdin.readline().strip()

        if response == '+':
            # Ход успешен, обновляем возможные позиции и записываем ход
            moves_made.append((dx, dy))
            new_positions = set()
            for x, y in possible_positions:
                new_x, new_y = x + dx, y + dy
                if 1 <= new_x <= 8 and 1 <= new_y <= 8:
                    new_positions.add((new_x, new_y))
            possible_positions = new_positions
        else:
            # Ход неудачен, оставляем только позиции, где ход невозможен
            new_positions = set()
            for x, y in possible_positions:
                new_x, new_y = x + dx, y + dy
                if not (1 <= new_x <= 8 and 1 <= new_y <= 8):
                    new_positions.add((x, y))
            possible_positions = new_positions

        if len(possible_positions) == 1:
            break

    # Восстанавливаем исходную позицию
    if possible_positions:
        current_x, current_y = next(iter(possible_positions))
        for dx, dy in reversed(moves_made):
            current_x -= dx
            current_y -= dy
        initial_position = coordinate_to_chess_notation(current_x, current_y)
        print(f"! {initial_position}")
        sys.stdout.flush()
    else:
        # Если не удалось определить позицию, выводим любую из оставшихся
        print("! a1")
        sys.stdout.flush()

if __name__ == "__main__":
    main()