#include <iostream>
#include <cmath>
#include <vector>

using namespace std;

const double EPS = 1e-6;

struct Point {
    double x, y;
    
    Point() : x(0), y(0) {}
    Point(double x, double y) : x(x), y(y) {}
    
    Point operator+(const Point& other) {
        return Point(x + other.x, y + other.y);
    }
    
    Point operator-(const Point& other) {
        return Point(x - other.x, y - other.y);
    }

    double distanceTo(const Point& other) const {
        return sqrt((x - other.x) * (x - other.x) + (y - other.y) * (y - other.y));
    }

    void print() const {
        cout.precision(6);
        cout << fixed << x << " " << y << endl;
    }
};

int main() {
    int x0, y0, x1, y1, n;
    cin >> x0 >> y0 >> x1 >> y1 >> n;
    
    vector<int> a(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i];
    }

    // Стартовая точка и конечная точка
    Point start(x0, y0);
    Point end(x1, y1);
    
    // Разница в координатах
    double dx = x1 - x0;
    double dy = y1 - y0;

    // Общая длина всех прыжков
    double total_distance = 0;
    for (int i = 0; i < n; i++) {
        total_distance += a[i];
    }

    // Если общая длина прыжков меньше, чем расстояние между стартом и финишем, то это невозможно
    if (total_distance < sqrt(dx * dx + dy * dy)) {
        cout << "Impossible" << endl;
        return 0;
    }

    // Начнем с начальной точки
    Point current = start;

    // Массив для хранения промежуточных точек
    vector<Point> points;
    points.push_back(current);

    // Пытаемся двигаться
    for (int i = 0; i < n; i++) {
        // Если у нас осталось расстояние до цели, нужно выбрать нормализованный вектор направления
        double remaining_dx = x1 - current.x;
        double remaining_dy = y1 - current.y;
        double remaining_distance = sqrt(remaining_dx * remaining_dx + remaining_dy * remaining_dy);

        // Направление для следующего прыжка
        double norm_x = remaining_dx / remaining_distance;
        double norm_y = remaining_dy / remaining_distance;

        // Следующая точка после прыжка
        Point next(current.x + norm_x * a[i], current.y + norm_y * a[i]);
        
        // Записываем следующую точку
        points.push_back(next);
        
        // Обновляем текущую точку
        current = next;
    }

    // Если последняя точка совпадает с конечной точкой, выводим результат
    if (fabs(current.x - x1) < EPS && fabs(current.y - y1) < EPS) {
        cout << "Possible" << endl;
        for (const auto& p : points) {
            p.print();
        }
    } else {
        cout << "Impossible" << endl;
    }

    return 0;
}