from collections import defaultdict

class ColorfulGraph:
    def __init__(self, n):
        self.n = n
        self.edge_count = defaultdict(int)  # храним количество рёбер каждого цвета
        self.vertex_color_count = [defaultdict(int) for _ in range(n + 1)]  # количество цветов у вершины
        self.superior_colors = set()  # набор превосходных цветов
        self.edge_connections = defaultdict(lambda: defaultdict(set))  # храним соединения рёбер для каждого цвета

    def add_edge(self, u, v, c):
        # Если ребро уже есть, не добавляем
        if v in self.edge_connections[u][c]:
            return

        self.edge_count[c] += 1
        self.vertex_color_count[u][c] += 1
        self.vertex_color_count[v][c] += 1
        self.edge_connections[u][c].add(v)
        self.edge_connections[v][c].add(u)

        # Проверяем, является ли цвет превосходным
        if self.edge_count[c] == 1:
            self.superior_colors.add(c)
        elif c in self.superior_colors:
            self.superior_colors.remove(c)

    def remove_edge(self, u, v, c):
        # Если ребра нет, не удаляем
        if v not in self.edge_connections[u][c]:
            return

        self.edge_count[c] -= 1
        self.vertex_color_count[u][c] -= 1
        self.vertex_color_count[v][c] -= 1
        self.edge_connections[u][c].remove(v)
        self.edge_connections[v][c].remove(u)

        # Проверяем, стал ли цвет превосходным
        if self.edge_count[c] == 1:
            self.superior_colors.add(c)
        elif self.edge_count[c] == 0:
            self.superior_colors.discard(c)

    def get_total_superior_colors(self):
        return len(self.superior_colors)


def solve():
    n, q = map(int, input().split())
    graph = ColorfulGraph(n)

    for _ in range(q):
        query = input().split()
        op, u, v, c = query[0], int(query[1]), int(query[2]), int(query[3])
        if op == '+':
            graph.add_edge(u, v, c)
        elif op == '-':
            graph.remove_edge(u, v, c)
        print(graph.get_total_superior_colors())


if __name__ == "__main__":
    solve()
