#include <iostream>
#include <unordered_map>
#include <unordered_set>
#include <vector>
#include <set>

using namespace std;

class ColorfulGraph {
private:
    int n;
    unordered_map<int, int> edge_count;  // храним количество рёбер каждого цвета
    vector<unordered_map<int, int>> vertex_color_count;  // количество цветов у вершины
    set<int> superior_colors;  // набор превосходных цветов
    unordered_map<int, unordered_map<int, unordered_set<int>>> edge_connections;  // храним соединения рёбер для каждого цвета

public:
    ColorfulGraph(int n) : n(n) {
        vertex_color_count.resize(n + 1);
    }

    void add_edge(int u, int v, int c) {
        // Если ребро уже есть, не добавляем
        if (edge_connections[u][c].count(v)) {
            return;
        }

        edge_count[c]++;
        vertex_color_count[u][c]++;
        vertex_color_count[v][c]++;
        edge_connections[u][c].insert(v);
        edge_connections[v][c].insert(u);

        // Проверяем, является ли цвет превосходным
        if (is_superior_color(c)) {
            superior_colors.insert(c);
        } else {
            superior_colors.erase(c);
        }
    }

    void remove_edge(int u, int v, int c) {
        // Если ребра нет, не удаляем
        if (!edge_connections[u][c].count(v)) {
            return;
        }

        edge_count[c]--;
        vertex_color_count[u][c]--;
        vertex_color_count[v][c]--;
        edge_connections[u][c].erase(v);
        edge_connections[v][c].erase(u);

        // Проверяем, стал ли цвет превосходным
        if (is_superior_color(c)) {
            superior_colors.insert(c);
        } else {
            superior_colors.erase(c);
        }
    }

    bool is_superior_color(int c) {
        // Цвет является превосходным, если все вершины соединены не более чем одним ребром этого цвета
        for (int u = 1; u <= n; ++u) {
            if (vertex_color_count[u][c] > 1) {
                return false;
            }
        }
        return edge_count[c] > 0;
    }

    int get_total_superior_colors() {
        return superior_colors.size();
    }
};

void solve() {
    int n, q;
    cin >> n >> q;
    ColorfulGraph graph(n);

    for (int i = 0; i < q; ++i) {
        char op;
        int u, v, c;
        cin >> op >> u >> v >> c;
        if (op == '+') {
            graph.add_edge(u, v, c);
        } else if (op == '-') {
            graph.remove_edge(u, v, c);
        }
        cout << graph.get_total_superior_colors() << endl;
    }
}

int main() {
    solve();
    return 0;
}
