#include <iostream>
#include <vector>
#include <unordered_map>
#include <unordered_set>
#include <set>
#include <tuple>
using namespace std;

struct Edge {
    int v, u;
    Edge(int a, int b) {
        v = min(a, b);
        u = max(a, b);
    }
    bool operator==(const Edge &other) const {
        return v == other.v && u == other.u;
    }
    bool operator<(const Edge &other) const {
        return tie(v, u) < tie(other.v, other.u);
    }
};

struct Hash {
    size_t operator()(const Edge &e) const {
        return hash<int>()(e.v) ^ hash<int>()(e.u);
    }
};

vector<int> process_queries(vector<tuple<char, int, int, int>> &queries) {
    unordered_map<int, unordered_set<Edge, Hash>> color_edges; // color -> set of edges
    unordered_map<int, unordered_map<int, int>> vertex_color_degree; // color -> vertex -> count
    unordered_map<int, int> color_beauty; // color -> current beauty
    int total_beauty = 0;
    vector<int> result;

    for (auto &[action, v, u, c] : queries) {
        Edge edge(v, u);
        if (action == '+') {
            color_edges[c].insert(edge);
            vertex_color_degree[c][v]++;
            vertex_color_degree[c][u]++;
            if (color_beauty[c] > 0) {
                total_beauty -= color_beauty[c];
            }
            bool valid = true;
            for (const auto &[_, degree] : vertex_color_degree[c]) {
                if (degree > 1) {
                    valid = false;
                    break;
                }
            }
            color_beauty[c] = valid ? color_edges[c].size() : 0;
            total_beauty += color_beauty[c];
        } else if (action == '-') {
            color_edges[c].erase(edge);
            vertex_color_degree[c][v]--;
            vertex_color_degree[c][u]--;
            if (color_beauty[c] > 0) {
                total_beauty -= color_beauty[c];
            }
            bool valid = true;
            for (const auto &[_, degree] : vertex_color_degree[c]) {
                if (degree > 1) {
                    valid = false;
                    break;
                }
            }
            color_beauty[c] = valid ? color_edges[c].size() : 0;
            total_beauty += color_beauty[c];
        }
        result.push_back(total_beauty);
    }
    return result;
}

int main() {
    int n, q;
    cin >> n >> q;
    vector<tuple<char, int, int, int>> queries;
    for (int i = 0; i < q; ++i) {
        char action;
        int v, u, c;
        cin >> action >> v >> u >> c;
        queries.emplace_back(action, v, u, c);
    }
    vector<int> results = process_queries(queries);
    for (int res : results) {
        cout << res << endl;
    }
    return 0;
}
