#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <queue>
using namespace std;

struct Segment {
    int l, r, id;
};

bool cmp(Segment a, Segment b) {
    return a.l < b.l;
}

bool can_form_sequence(const vector<int>& p, const vector<int>& runes, const vector<Segment>& segments, vector<int>& result) {
    int n = p.size();
    int m = runes.size();
    vector<int> position(n + 1, -1);
    for (int i = 0; i < n; ++i) {
        position[p[i]] = i;
    }

    vector<vector<int>> occurrences(n);
    for (int i = 0; i < m; ++i) {
        if (position[runes[i]] != -1) {
            occurrences[position[runes[i]]].push_back(i);
        }
    }

    vector<int> last(n, -1);
    for (int i = 0; i < n; ++i) {
        if (occurrences[i].empty()) {
            return false;
        }
        last[i] = occurrences[i].back();
        occurrences[i].pop_back();
    }

    set<int> active;
    vector<int> next_free(n, -1);
    for (int i = n - 1; i >= 0; --i) {
        active.insert(last[i]);
        if (i + 1 < n) {
            next_free[i] = next_free[i + 1];
        }
        while (!occurrences[i].empty()) {
            next_free[i] = occurrences[i].back();
            occurrences[i].pop_back();
        }
    }

    priority_queue<pair<int, int>, vector<pair<int, int>>, greater<pair<int, int>>> pq;
    for (const auto& seg : segments) {
        pq.push({seg.r, seg.id});
    }

    int current_pos = -1;
    while (!pq.empty()) {
        auto [r, id] = pq.top();
        pq.pop();
        int l = segments[id].l - 1;
        if (current_pos < l && r >= last[0] && active.count(r)) {
            current_pos = r;
            result.push_back(id);
            active.erase(r);
        }
    }

    return active.empty();
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(0);

    int t;
    cin >> t;

    while (t--) {
        int n, m, k;
        cin >> n >> m >> k;

        vector<int> p(n);
        for (int i = 0; i < n; ++i) {
            cin >> p[i];
        }

        vector<int> runes(m);
        for (int i = 0; i < m; ++i) {
            cin >> runes[i];
        }

        vector<Segment> segments(k);
        for (int i = 0; i < k; ++i) {
            cin >> segments[i].l >> segments[i].r;
            segments[i].id = i + 1;
        }

        vector<int> result;
        if (can_form_sequence(p, runes, segments, result)) {
            cout << result.size() << "\n";
            for (int i : result) {
                cout << i << " ";
            }
            cout << "\n";
        } else {
            cout << -1 << "\n";
        }
    }

    return 0;
}
