import math

def parse_input(input_str):
    parts = input_str.strip().split()
    if len(parts) != 6:
        raise ValueError("Введите три координаты в формате 'x1 y1 x2 y2 x3 y3'")
    points = []
    for i in range(0, 6, 2):
        x = float(parts[i])
        y = float(parts[i+1])
        points.append((x, y))
    return points

def median(lst):
    sorted_lst = sorted(lst)
    n = len(sorted_lst)
    mid = n // 2
    if n % 2 == 1:
        return sorted_lst[mid]
    else:
        return (sorted_lst[mid-1] + sorted_lst[mid]) / 2

def find_best_line(points, steps=10000):
    min_sum = float('inf')
    best_theta = 0
    best_c = 0
    for step in range(steps):
        theta = math.pi * step / steps
        a = math.sin(theta)
        b = -math.cos(theta)
        projections = [a * x + b * y for (x, y) in points]
        median_proj = median(projections)
        c = -median_proj
        distances = [abs(a * x + b * y + c) for (x, y) in points]
        total = sum(distances)
        if total < min_sum:
            min_sum = total
            best_theta = theta
            best_c = c
    return best_theta, best_c

def get_two_points(theta, c):
    a = math.sin(theta)
    b = -math.cos(theta)
    if abs(b) > 1e-6:
        y1 = (-c) / b
        y2 = (-c - a * 1) / b
        point1 = (0, y1)
        point2 = (1, y2)
    else:
        x = (-c) / a
        point1 = (x, 0)
        point2 = (x, 1)
    return point1, point2

def round_if_close(x, tol=1e-6):
    if abs(x - round(x)) < tol:
        return int(round(x))
    else:
        return round(x, 6)

def format_output(p1, p2):
    return f"{p1[0]} {p1[1]} {p2[0]} {p2[1]}"

def main():
    input_str = input()
    points = parse_input(input_str)
    theta, c = find_best_line(points)
    p1, p2 = get_two_points(theta, c)
    p1 = (round_if_close(p1[0]), round_if_close(p1[1]))
    p2 = (round_if_close(p2[0]), round_if_close(p2[1]))
    output_str = format_output(p1, p2)
    print(output_str)

if __name__ == "__main__":
    main()
