class Graph:
    def __init__(self):
        self.edges = {}
        self.colors = {}

    def add_edge(self, v, u, c):
        if c not in self.edges:
            self.edges[c] = set()
        self.edges[c].add((v, u))
        self.colors[(v, u)] = c

    def remove_edge(self, v, u, c):
        if c in self.edges and (v, u) in self.edges[c]:
            self.edges[c].remove((v, u))
            del self.colors[(v, u)]

    def calculate_beauty(self):
        beauty = 0
        for color, edges in self.edges.items():
            vertex_count = {}
            for v, u in edges:
                if v not in vertex_count:
                    vertex_count[v] = 0
                if u not in vertex_count:
                    vertex_count[u] = 0
                vertex_count[v] += 1
                vertex_count[u] += 1
            
            if all(count == 1 for count in vertex_count.values()):
                beauty += len(edges)
        return beauty

# Пример использования
def main():
    n, q = map(int, input().split())
    graph = Graph()
    
    for _ in range(q):
        query = input().split()
        action = query[0]
        v = int(query[1])
        u = int(query[2])
        c = int(query[3])
        
        if action == "+":
            graph.add_edge(v, u, c)
        elif action == "-":
            graph.remove_edge(v, u, c)
        
        beauty = graph.calculate_beauty()
        print(beauty)

if __name__ == "__main__":
    main()
