import math

def distance(x0, y0, x1, y1):
    return math.sqrt((x1 - x0) ** 2 + (y1 - y0) ** 2)

def jump_path(x0, y0, x1, y1, n, jumps):

    target_distance = distance(x0, y0, x1, y1)
    total_jump_distance = sum(jumps)
    
    if abs(total_jump_distance - target_distance) > 1e-4:
        return "Impossible"
    
    path = [(x0, y0)]
    current_x, current_y = x0, y0
    
    for i in range(n):
        remaining_distance = distance(current_x, current_y, x1, y1)
        
        if i == n - 1:
            next_x, next_y = x1, y1
        else:

            ratio = jumps[i] / remaining_distance
            next_x = current_x + (x1 - current_x) * ratio
            next_y = current_y + (y1 - current_y) * ratio
        

        path.append((next_x, next_y))
        current_x, current_y = next_x, next_y


    if distance(current_x, current_y, x1, y1) > 1e-4:
        return "Impossible"
    
    return "Possible", path

x0, y0 = map(int, input().split())
x1, y1 = map(int, input().split())
n = int(input())
jumps = list(map(int, input().split()))

result = jump_path(x0, y0, x1, y1, n, jumps)

if result == "Impossible":
    print("Impossible")
else:
    print("Possible")
    for x, y in result[1]:
        print(f"{x:.8f} {y:.8f}")
