#include <bits/stdc++.h>

using namespace std;

//@formatter:off
using ll = long long;
template<typename T> istream &operator>>(istream &is, vector<T> &a);
template<typename T> ostream &operator<<(ostream &os, vector<T> &a);
//@formatter:on
using ld = long double;

//@formatter:off
 namespace geo {
     struct Point {
         double x, y;

         Point() : x(0), y(0) {};
         Point(double x, double y) : x(x), y(y) {};
         Point(double x1, double y1, double x2, double y2) : x(x2 - x1), y(y2 - y1) {};
         Point(Point start, Point end) : x(end.x - start.x), y(end.y - start.y) {};

         void read(){ Point a, b; cin >> a >> b; *this=Point(a, b); }

         long long len() { return 1ll * x * x + 1ll * y * y; }
         long double lenf() { return sqrtl(1ll * x * x + 1ll * y * y); }

         friend istream &operator>>(istream &is, Point &a) { is >> a.x >> a.y; return is; }
         friend ostream &operator<<(ostream &os, Point a) { os << (int)a.x << " " << (int)a.y; return os; }

         friend Point operator+(Point a, Point b) { return Point(a.x + b.x, a.y + b.y); }
         friend Point operator-(Point a, Point b) { return Point(a.x - b.x, a.y - b.y); }
         friend Point operator/(Point a, double b) { return Point(a.x / b, a.y / b); }
         friend long long operator*(Point a, Point b) { return 1ll * a.x * b.x + 1ll * a.y * b.y; }
         friend Point operator*(Point a, double b) { return Point(a.x * b, a.y * b); }
         friend long long operator%(Point a, Point b) { return 1ll * a.x * b.y - 1ll * a.y * b.x; }
     };

     struct Segment {
         Point begin, end;

         Segment() : begin(), end() {};
         Segment(Point begin, Point end) : begin(begin), end(end) {};
     };

     struct Ray {
         Point begin, end;

         Ray() : begin(), end() {};
         Ray(Point from, Point to) : begin(from), end(to) {};
     };

     struct Line {
         double a, b, c;
         Line() : a(), b(), c() {};
         Line(Point from, Point to) {
             a = to.y - from.y;
             b = from.x - to.x;
             c = -(a * from.x + b * from.y);
         };
         Line(double a, double b, double c) : a(a), b(b), c(c) {};

         void read(){ int aa,bb,cc; cin >> aa >> bb >> cc; *this=Line(aa, bb, cc); }

         Point parallelZero() { return Point(-b, a) / Point(-b, a).lenf(); }
         Point parallel() { return Point(-b, a); }
         Point perpendicularZero() { return Point(a, b) / Point(a, b).lenf(); }
         Point perpendicular() { return Point(a, b); }
         Point operator()(double x) { return Point(x, -double((x*a+c)) / b); }


     };

     Point intersect(Line ln1, Line ln2){
         double y = (ln2.a * ln1.c - ln1.a * ln2.c) / (ln1.a * ln2.b - ln2.a * ln1.b);
         double x = 0;
         if (ln1.a == 0) x = (-ln2.b * y - ln2.c) / ln2.a;
         else x = (-ln1.b * y - ln1.c) / ln1.a;

         return Point(x, y);
     }

     bool touch(Point a, Line b){
         return b(a.x).y == a.y;
     }
     bool touch(Point a, Ray b){
         return touch(a, Line(b.begin, b.end)) && Point(a, b.begin) * Point(b.begin, b.end) <= 0;
     }
     bool touch(Point a, Segment b){
         return touch(a, Ray(b.begin, b.end)) && touch(a, Ray(b.end, b.begin));
     }

     double distance(Point a, Point b){
         return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
     }

     double distance(Point a, Line b){
         return abs(double(b.a * a.x + b.b * a.y + b.c) / sqrt(b.a * b.a + b.b * b.b));
     }

     double distance(Point a, Ray b){
         if (Point(b.begin, a) * Point(b.begin, b.end) >= 0) return distance(a, Line(b.begin, b.end));
         else return min(distance(a, b.begin), distance(a, b.end));
     }

     double distance(Point a, Segment b){
         if (Point(b.begin, a) * Point(b.begin, b.end) >= 0 &&
             Point(b.end, a) * Point(b.end, b.begin) >= 0) return distance(a, Line(b.begin, b.end));
         else return min(distance(a, b.begin), distance(a, b.end));
     }

     double distance(Line a, Line b){
         if (a.parallel() % b.parallel() == 0) {
             Line ln(-a.b, a.a, 0);
             Point p1 = intersect(a, ln);
             Point p2 = intersect(b, ln);
             return distance(p1, p2);
         };
         return 0;
     }



     void angle(Point a, Point b) { acos(double(a * b) / a.lenf() / b.lenf()); }
 }
 //@formatter:on
using namespace geo;


signed main() {
#ifdef LOCAL
      freopen("input.txt", "r", stdin);
      freopen("output.txt", "w", stdout);
#else
      ios_base::sync_with_stdio(false);
      cin.tie(0);
#endif
      vector<Point> a(3);
      cin >> a;


      ld mn = 1e18;
      int resi = -1;
      for (int i = 0; i < 3; ++i) {
            for (int j = i + 1; j < 3; ++j) {
                  Line l(a[i], a[j]);
                  double dist = distance(a[0 ^ 1 ^ 2 ^ i ^ j], l);
                  if (dist < mn) {
                        resi = 0 ^ 1 ^ 2 ^ i ^ j;
                        mn = dist;
                  }
            }
      }

      assert(resi != -1);
      for (int i = 0; i < 3; ++i) {
            if (resi == i) continue;
            cout << a[i] << ' ';
      }
}

// region POZOR
template<typename T>
ostream &operator<<(ostream &os, vector<T> &a) {
      for (int i = 0; i < a.size(); i++)
            os << a[i] << " \n"[i == a.size() - 1];
      return os;
}

template<typename T>
istream &operator>>(istream &is, vector<T> &a) {
      for (auto &i: a)
            is >> i;
      return is;
}
// endregion