#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
using namespace std;

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    
    int n;
    cin >> n;
    
    // Read input
    vector<pair<long long, long long>> cards(n);  // {front, back}
    for(int i = 0; i < n; i++) {
        cin >> cards[i].first;
    }
    for(int i = 0; i < n; i++) {
        cin >> cards[i].second;
    }
    
    // Try both orientations for each card
    vector<pair<pair<long long, long long>, int>> possiblePositions;  // {{front, back}, card_index}
    for(int i = 0; i < n; i++) {
        // Normal orientation
        possiblePositions.push_back({{cards[i].first, cards[i].second}, i});
        // Flipped orientation
        possiblePositions.push_back({{cards[i].second, cards[i].first}, i});
    }
    
    // Sort by front value
    sort(possiblePositions.begin(), possiblePositions.end());
    
    vector<long long> front_result, back_result;
    set<int> used_cards;
    long long last_front = -1, last_back = -1;
    
    for(auto& pos : possiblePositions) {
        int card_idx = pos.second;
        long long front = pos.first.first;
        long long back = pos.first.second;
        
        // Skip if card already used
        if(used_cards.count(card_idx)) continue;
        
        // Check if this card can be next in sequence
        if((last_front == -1 || front > last_front) && (last_back == -1 || back > last_back)) {
            used_cards.insert(card_idx);
            front_result.push_back(front);
            back_result.push_back(back);
            last_front = front;
            last_back = back;
        }
    }
    
    // Check if we used all cards and sequences are strictly increasing
    if(used_cards.size() != n) {
        cout << "-1\n";
        return 0;
    }
    
    // Output result
    for(int i = 0; i < n; i++) {
        cout << front_result[i] << (i == n-1 ? '\n' : ' ');
    }
    for(int i = 0; i < n; i++) {
        cout << back_result[i] << (i == n-1 ? '\n' : ' ');
    }
    
    return 0;
}