def distance_to_line(a, b, c, x, y):
    """Вычисляет расстояние от точки (x, y) до прямой ax + by + c = 0"""
    return abs(a * x + b * y + c) / ((a ** 2 + b ** 2) ** 0.5)


def calculate_min_line(x1, y1, x2, y2, x3, y3):
    import itertools

    # Кандидаты на прямые
    candidates = []

    # Горизонтальные прямые
    candidates.append((0, 1, -y1))  # y = y1
    candidates.append((0, 1, -y2))  # y = y2
    candidates.append((0, 1, -y3))  # y = y3

    # Вертикальные прямые
    candidates.append((1, 0, -x1))  # x = x1
    candidates.append((1, 0, -x2))  # x = x2
    candidates.append((1, 0, -x3))  # x = x3

    # Прямые через пары точек
    points = [(x1, y1), (x2, y2), (x3, y3)]
    for (x1, y1), (x2, y2) in itertools.combinations(points, 2):
        # Коэффициенты прямой через (x1, y1) и (x2, y2): (y2-y1)x - (x2-x1)y + c = 0
        a = y2 - y1
        b = x1 - x2
        c = -(a * x1 + b * y1)
        candidates.append((a, b, c))

    # Выбор оптимальной прямой
    min_distance = float('inf')
    best_line = None
    for a, b, c in candidates:
        total_distance = (
                distance_to_line(a, b, c, x1, y1) +
                distance_to_line(a, b, c, x2, y2) +
                distance_to_line(a, b, c, x3, y3)
        )
        if total_distance < min_distance:
            min_distance = total_distance
            best_line = (a, b, c)

    # Найдём две точки на лучшей прямой
    a, b, c = best_line
    if b == 0:  # Вертикальная прямая
        x = -c // a
        return (x, 0), (x, 1)
    else:  # Остальные случаи
        return (0, -c // b), (1, -(c + a) // b)


# Ввод
x1, y1, x2, y2, x3, y3 = map(int, input().split())

# Вычисление оптимальной прямой
point1, point2 = calculate_min_line(x1, y1, x2, y2, x3, y3)

# Вывод
print(*point1, *point2)
