﻿#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>
#include <iomanip>
#include <limits>

using namespace std;

struct Station {
    long long x;
    long long t; 
};


struct State {
    double time; 
    long long position; 


    bool operator>(const State& other) const {
        return time > other.time;
    }
};

int main() {
  
    int n;
    long long m, c;
    cin >> n >> m >> c;

    vector<Station> stations(n);
    for (int i = 0; i < n; ++i) {
        cin >> stations[i].x >> stations[i].t;
    }

   
    stations.push_back({ 0, 0 });    
    stations.push_back({ m, 0 });    

   
    sort(stations.begin(), stations.end(), [](const Station& a, const Station& b) {
        return a.x < b.x;
        });

   
    priority_queue<State, vector<State>, greater<State>> pq;
    vector<double> min_time(n + 2, numeric_limits<double>::infinity()); 
    min_time[0] = 0;
    pq.push({ 0, 0 });

    while (!pq.empty()) {
        State current = pq.top();
        pq.pop();

        if (current.time > min_time[current.position]) continue;

      
        for (int next = current.position + 1; next < n + 2; ++next) {
            long long dist = stations[next].x - stations[current.position].x;
            if (dist > c) break;

     
            double travel_time = static_cast<double>(dist) * dist / c;
            double total_time = current.time + travel_time + stations[current.position].t;

        
            if (total_time < min_time[next]) {
                min_time[next] = total_time;
                pq.push({ total_time, next });
            }
        }
    }

  
    cout << fixed << setprecision(6) << min_time[n + 1] << endl;

  
}
