# Определяем класс для управления графом и цветами
class GraphColors:
    def __init__(self):
        # Словарь для хранения рёбер по цветам
        self.color_to_edges = {}
        # Переменная для отслеживания количества превосходных цветов
        self.superior_count = 0

    def add_edge(self, u, v, c):
        edge = tuple(sorted((u, v)))
        if c not in self.color_to_edges:
            self.color_to_edges[c] = set()
        # Проверяем, был ли цвет ранее превосходным
        if len(self.color_to_edges[c]) == 1:
            self.superior_count -= 1
        # Добавляем ребро
        self.color_to_edges[c].add(edge)
        # Проверяем, стал ли цвет превосходным
        if len(self.color_to_edges[c]) == 1:
            self.superior_count += 1

    def remove_edge(self, u, v, c):
        edge = tuple(sorted((u, v)))
        if c in self.color_to_edges and edge in self.color_to_edges[c]:
            # Проверяем, был ли цвет ранее превосходным
            if len(self.color_to_edges[c]) == 1:
                self.superior_count -= 1
            # Удаляем ребро
            self.color_to_edges[c].remove(edge)
            # Если цвет больше не имеет рёбер, удаляем его из словаря
            if not self.color_to_edges[c]:
                del self.color_to_edges[c]
            else:
                # Проверяем, стал ли цвет превосходным после удаления
                if len(self.color_to_edges[c]) == 1:
                    self.superior_count += 1

    def get_superior_count(self):
        return self.superior_count

# Основная часть программы
def main():
    import sys

    import sys

    import sys
    # Чтение числа вершин и запросов
    n, q = map(int, sys.stdin.readline().split())
    graph = GraphColors()

    for _ in range(q):
        parts = sys.stdin.readline().split()
        if not parts:
            continue  # Пропустить пустые строки
        op = parts[0]
        u = int(parts[1])
        v = int(parts[2])
        c = int(parts[3])
        if op == '+':
            graph.add_edge(u, v, c)
        elif op == '-':
            graph.remove_edge(u, v, c)
        # Вывод текущей суммы красот (количества превосходных цветов)
        print(graph.get_superior_count())

if __name__ == "__main__":
    main()


